<?php

namespace Drupal\wp_publish\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use GuzzleHttp\ClientInterface;

/**
 * Service for publishing Drupal nodes to WordPress via REST API.
 */
class WpPublishService {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Constructs a WpPublishService object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \GuzzleHttp\ClientInterface $http_client
   *   The HTTP client.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger channel factory.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    ClientInterface $http_client,
    LoggerChannelFactoryInterface $logger_factory
  ) {
    $this->configFactory = $config_factory;
    $this->httpClient = $http_client;
    $this->logger = $logger_factory->get('wp_publish');
  }

  /**
   * Publishes a node to WordPress.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The node to publish.
   *
   * @throws \GuzzleHttp\Exception\GuzzleException
   *   If the API request fails.
   */
  public function publishNode($node) {
    $config = $this->configFactory->get('wp_publish.settings');
    $wordpress_url = $config->get('wordpress_url');
    $username = $config->get('wordpress_username');
    $app_password = $config->get('wordpress_app_password');

    if (!$wordpress_url || !$username || !$app_password) {
      $this->logger->error('WordPress configuration is incomplete.');
      return;
    }

    $post_data = [
      'title' => $node->getTitle(),
      'content' => $node->body->value,
      'status' => 'publish',
    ];

    try {
      $response = $this->httpClient->post($wordpress_url . '/wp-json/wp/v2/posts', [
        'auth' => [$username, $app_password],
        'json' => $post_data,
      ]);

      $this->logger->info('Node @nid published to WordPress.', ['@nid' => $node->id()]);
    }
    catch (\Exception $e) {
      $this->logger->error('Failed to publish node @nid to WordPress: @error', [
        '@nid' => $node->id(),
        '@error' => $e->getMessage(),
      ]);
    }
  }
}
